@@ -38,7 +38,7 @@
 #define countof(a) (sizeof(a)/sizeof(*(a)))
 
 static void
-_fill_map (uint32_t c, const uint8_t * p, IDNAMap * map)
+_fill_map (uint32_t c, const uint8_t *p, IDNAMap *map)
 {
   uint32_t value;
 
@@ -70,7 +70,7 @@ _fill_map (uint32_t c, const uint8_t * p, IDNAMap * map)
 }
 
 static int
-_compare_idna_map (const uint32_t * c, const uint8_t * p)
+_compare_idna_map (const uint32_t *c, const uint8_t *p)
 {
   IDNAMap map;
 
@@ -102,22 +102,25 @@ IDNAMap
 */
 
 int
-get_idna_map (uint32_t c, IDNAMap * map)
+get_idna_map (uint32_t c, IDNAMap *map)
 {
   uint8_t *p;
 
   if (c <= 0xFF)
     p =
-      (uint8_t *)bsearch (&c, idna_map_8, sizeof (idna_map_8) / 5, 5,
-	       (int (*)(const void *, const void *)) _compare_idna_map);
+      (uint8_t *) bsearch (&c, idna_map_8, sizeof (idna_map_8) / 5, 5,
+			   (int (*)(const void *, const void *))
+			   _compare_idna_map);
   else if (c <= 0xFFFF)
     p =
-      (uint8_t *)bsearch (&c, idna_map_16, sizeof (idna_map_16) / 7, 7,
-	       (int (*)(const void *, const void *)) _compare_idna_map);
+      (uint8_t *) bsearch (&c, idna_map_16, sizeof (idna_map_16) / 7, 7,
+			   (int (*)(const void *, const void *))
+			   _compare_idna_map);
   else if (c <= 0xFFFFFF)
     p =
-      (uint8_t *)bsearch (&c, idna_map_24, sizeof (idna_map_24) / 8, 8,
-	       (int (*)(const void *, const void *)) _compare_idna_map);
+      (uint8_t *) bsearch (&c, idna_map_24, sizeof (idna_map_24) / 8, 8,
+			   (int (*)(const void *, const void *))
+			   _compare_idna_map);
   else
     p = NULL;
 
@@ -132,13 +135,13 @@ get_idna_map (uint32_t c, IDNAMap * map)
 }
 
 int
-map_is (const IDNAMap * map, unsigned flags)
+map_is (const IDNAMap *map, unsigned flags)
 {
   return (idna_flags[map->flag_index] & flags) == flags;
 }
 
 static int G_GNUC_IDN2_ATTRIBUTE_PURE
-_compare_nfcqc_map (uint32_t * c, NFCQCMap * m2)
+_compare_nfcqc_map (uint32_t *c, NFCQCMap *m2)
 {
   if (*c < m2->cp1)
     return -1;
@@ -150,13 +153,15 @@ _compare_nfcqc_map (uint32_t * c, NFCQCMap * m2)
 NFCQCMap *
 get_nfcqc_map (uint32_t c)
 {
-  return (NFCQCMap *)bsearch (&c, nfcqc_map, countof (nfcqc_map), sizeof (NFCQCMap),
-		  (int (*)(const void *, const void *)) _compare_nfcqc_map);
+  return (NFCQCMap *) bsearch (&c, nfcqc_map, countof (nfcqc_map),
+			       sizeof (NFCQCMap),
+			       (int (*)(const void *, const void *))
+			       _compare_nfcqc_map);
 }
 
 /* copy 'n' codepoints from mapdata stream */
 int
-get_map_data (uint32_t * dst, const IDNAMap * map)
+get_map_data (uint32_t *dst, const IDNAMap *map)
 {
   int n = map->nmappings;
   const uint8_t *src = mapdata + map->offset;
